function v=compute_tangential_surge_a1(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes tangential_surge_a1
% Script automatically generated by fit_tangential_surge_a1.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.82881
% RMSE  = 0.049513
% MEAN  = 0.21327
% RANGE = 0.10293 - 0.59645

beta( 1 )= 3.7335e-04 ;
beta( 2 )= 2.9230e-02 ;
beta( 3 )= 3.4115e-01 ;
beta( 4 )= 1.0000e+00 ;
beta( 5 )= 3.6261e-02 ;
beta( 6 )= 9.3323e-01 ;

v=beta(1) * exp(-a/beta(2)) .* w.^beta(3) .* (beta(4)+beta(5).*vt.*cos(phi*pi/180)) .* vmax.^beta(6);
